"""
    Python with RabbitMQ—simplified so you won't have to.

    :copyright: 2020-Present by Alexandre Gerona.
    :license: MIT, see LICENSE for more details.

    Full documentation is available at https://pyrmq.readthedocs.io
"""

import pytest
from pyrmq import Publisher

TEST_EXCHANGE_NAME = "sample_exchange"
TEST_QUEUE_NAME = "test_queue_name"
TEST_ROUTING_KEY = "test_routing_key"


@pytest.fixture(scope="session")
def publisher():
    publisher = Publisher(
        exchange_name=TEST_EXCHANGE_NAME,
        queue_name=TEST_QUEUE_NAME,
        routing_key=TEST_ROUTING_KEY,
    )
    return publisher


@pytest.fixture(scope="function")
def publisher_session(publisher):
    # Delete queue generated by Publisher on test setup
    _, channel = publisher.connect()
    channel.queue_purge(TEST_QUEUE_NAME)
    yield publisher
    # Delete queue generated by Publisher on test teardown
    channel = list(publisher.channels.values())[0]
    channel.queue_purge(TEST_QUEUE_NAME)
